=== modified file 'Makefile'
--- Makefile	2009-05-16 18:22:49 +0000
+++ Makefile	2010-04-15 11:50:22 +0000
@@ -19,7 +19,7 @@
 	
 install:
 	mkdir -p $(DESTDIR)$(etcdir)/etckeeper/ $(DESTDIR)$(vardir)/cache/etckeeper/
-	cp -a *.d $(DESTDIR)$(etcdir)/etckeeper/
+	cp -dR *.d $(DESTDIR)$(etcdir)/etckeeper/
 	$(INSTALL_DATA) $(CONFFILE) $(DESTDIR)$(etcdir)/etckeeper/etckeeper.conf
 	$(INSTALL_EXE) etckeeper $(DESTDIR)$(sbindir)/etckeeper
 	$(INSTALL_DATA) etckeeper.8 $(DESTDIR)$(mandir)/man8/etckeeper.8
@@ -43,6 +43,7 @@
 	rm -rf build
 
 etckeeper.spec:
-	sed -i "s/Version:.*/Version: $$(perl -e '$$_=<>;print m/\((.*?)\)/'<debian/changelog)/" etckeeper.spec
+	sed -i~ "s/Version:.*/Version: $$(perl -e '$$_=<>;print m/\((.*?)\)/'<debian/changelog)/" etckeeper.spec
+	rm -f etckeeper.spec~
 
 .PHONY: etckeeper.spec

=== modified file 'README'
--- README	2009-03-02 17:01:09 +0000
+++ README	2010-04-15 11:50:22 +0000
@@ -6,6 +6,7 @@
 configurable, while also being simple to use if you understand the basics
 of working with version control.
 
+
 ## security warnings
 
 First, a big warning: By checking /etc into version control, you are
@@ -149,8 +150,9 @@
 remote clone is mode 700! (And, obviously, only push over a secure
 transport like ssh, and only to a server you trust.)
 
-	ssh server 'mkdir /etc-clone; cd /etc-clone; chmod 700 .; git init'
-	git push ssh://server/etc-clone master
+	ssh server 'mkdir /etc-clone; cd /etc-clone; chmod 700 .; git init --bare'
+	git remote add backup ssh://server/etc-clone
+	git push backup --all
 
 If you have several machine's using etckeeper, you can start with a
 etckeeper repository on one machine, then add another machine's etckeeper
@@ -206,6 +208,14 @@
 
 	chmod -x /etc/etckeeper/commit.d/50vcs-commit
 
+Here's how to make it automatically push commits to a clone of the
+repository as a backup (see instructions above to set up the clone safely):
+
+	cd /etc/etckeeper/commit.d
+	(echo '#!/bin/sh' ; echo 'git push backup') > 99git-push
+	chmod +x 99git-push
+	git add .
+	git commit -m "automatically push commits to backup repository"
 
 ## changing VCS
 

=== modified file 'commit.d/50vcs-commit'
--- commit.d/50vcs-commit	2010-02-18 14:01:45 +0000
+++ commit.d/50vcs-commit	2010-04-15 11:50:22 +0000
@@ -2,7 +2,11 @@
 set -e
 
 message="$1"
-hostname=`hostname -f 2>/dev/null || hostname`
+hostname=`hostname`
+dnsdomainname=`dnsdomainname 2>/dev/null || true`
+if [ -n "$dnsdomainname" ]; then
+	hostname="$hostname.$dnsdomainname"
+fi
 
 USER=
 if [ -n "$SUDO_USER" ]; then
@@ -47,10 +51,14 @@
 elif [ "$VCS" = darcs ] && [ -d _darcs ]; then
 	logfile="$(mktemp -t etckeeper-$VCS.XXXXXXXXXX)"
 	printf "%b" "$message" > "$logfile"
-	if [ -n "$USER" ]; then
-		echo "(committed by $USER)" >> "$logfile"
-	fi
-	darcs record $DARCS_COMMIT_OPTIONS --logfile="$logfile"
+	if [ -z "$USER" ]; then
+		USER=root
+	fi
+	if [ -n "$message" ]; then
+		darcs record --author="$USER" $DARCS_COMMIT_OPTIONS --logfile="$logfile"
+	else
+		darcs record --author="$USER" $DARCS_COMMIT_OPTIONS
+	fi
 	rm -f "$logfile"
 	unset logfile
 fi

=== modified file 'debian/changelog'
--- debian/changelog	2010-02-18 14:01:45 +0000
+++ debian/changelog	2010-04-15 11:50:22 +0000
@@ -1,3 +1,30 @@
+etckeeper (0.45) unstable; urgency=low
+
+  * Revert darcs to using --logfile again, necessary for multiline commit
+    messages. Closes: #577915
+  * Fix logic error in darcs user code. Closes: #577918
+
+ -- Joey Hess <joeyh@debian.org>  Thu, 15 Apr 2010 11:50:22 -0400
+
+etckeeper (0.44) unstable; urgency=low
+
+  * Add example to README of how to automatically push changes to a backup
+    repository.
+  * Add fuse lock file to ignore list.
+  * Changed darcs to specify --author instead of noting the committing
+    user inside the commit log.
+  * Add -a to DARCS_COMMIT_OPTIONS so commits are noninteractive by default,
+    but users who want darcs prompting can disable it.
+  * Use darcs record -m to specify commit message, instead of using a logfile.
+  * Closes: #519228
+  * Update depends for git-core to git transition. Closes: #577732
+  * Avoid using hostname -f, since on Solaris that sets the hostname to -f.
+    Yay, Unix portability! (Instead, use dnsdomainname if available, and
+    otherwise, fall back to the unqualified hostname.)
+  * Other portability fixes for non-GNU tools and OS X. Thanks, Neil Mayhew.
+
+ -- Joey Hess <joeyh@debian.org>  Wed, 14 Apr 2010 15:43:14 -0400
+
 etckeeper (0.43) unstable; urgency=low
 
   * Fix cleanup of /var/cache/etckeeper/packagelist.pre-install after

=== modified file 'debian/control'
--- debian/control	2010-02-18 14:01:45 +0000
+++ debian/control	2010-04-15 11:50:22 +0000
@@ -11,7 +11,7 @@
 Package: etckeeper
 Architecture: all
 Section: admin
-Depends: git-core (>= 1:1.5.4) | mercurial | bzr (>= 1.4~) | darcs, ${misc:Depends}
+Depends: git-core (>= 1:1.5.4) | git (>= 1:1.7) | mercurial | bzr (>= 1.4~) | darcs, ${misc:Depends}
 Recommends: cron
 Conflicts: bzr (<< 1.4~)
 XB-Python-Version: ${python:Versions}

=== modified file 'etckeeper.conf'
--- etckeeper.conf	2009-02-25 14:38:12 +0000
+++ etckeeper.conf	2010-04-15 11:50:22 +0000
@@ -1,20 +1,20 @@
 # The VCS to use.
-# VCS="hg"
+#VCS="hg"
 VCS="git"
-# VCS="bzr"
-# VCS="darcs"
+#VCS="bzr"
+#VCS="darcs"
 
 # Options passed to git commit when run by etckeeper.
-#GIT_COMMIT_OPTIONS=""
+GIT_COMMIT_OPTIONS=""
 
 # Options passed to hg commit when run by etckeeper.
-#HG_COMMIT_OPTIONS=""
+HG_COMMIT_OPTIONS=""
 
 # Options passed to bzr commit when run by etckeeper.
-#BZR_COMMIT_OPTIONS=""
+BZR_COMMIT_OPTIONS=""
 
-# Options passed to darcs commit when run by etckeeper.
-#DARCS_COMMIT_OPTIONS=""
+# Options passed to darcs record when run by etckeeper.
+DARCS_COMMIT_OPTIONS="-a"
 
 # Uncomment to avoid etckeeper committing existing changes
 # to /etc automatically once per day.

=== modified file 'etckeeper.spec'
--- etckeeper.spec	2010-02-18 14:01:45 +0000
+++ etckeeper.spec	2010-04-15 11:50:22 +0000
@@ -1,5 +1,5 @@
 Name: etckeeper
-Version: 0.43
+Version: 0.45
 Release: 4%{?dist}
 Summary: store /etc in git, mercurial, bzr or darcs
 

=== modified file 'pre-commit.d/20warn-hardlinks'
--- pre-commit.d/20warn-hardlinks	2009-02-12 17:13:23 +0000
+++ pre-commit.d/20warn-hardlinks	2010-04-15 11:50:22 +0000
@@ -2,7 +2,7 @@
 set -e
 
 if [ "$VCS" = git ] || [ "$VCS" = hg ] || [ "$VCS" = bzr ] || [ "$VCS" = darcs ]; then
-	hardlinks=$(find -type f -not -links 1 | grep -v '/\(.git\|.hg\|.bzr\|_darcs\)/' ) || true
+	hardlinks=$(find . -type f -not -links 1 | grep -v '/\(.git\|.hg\|.bzr\|_darcs\)/' ) || true
 	if [ -n "$hardlinks" ]; then
 		echo "etckeeper warning: hardlinked files could cause problems with $VCS:" >&2
 		echo "$hardlinks" >&2

=== modified file 'pre-commit.d/20warn-special-file'
--- pre-commit.d/20warn-special-file	2009-02-12 17:13:23 +0000
+++ pre-commit.d/20warn-special-file	2010-04-15 11:50:22 +0000
@@ -2,7 +2,7 @@
 set -e
 
 if [ "$VCS" = git ] || [ "$VCS" = hg ] || [ "$VCS" = bzr ] || [ "$VCS" = darcs ]; then
-	special=$(find -not -type d -not -type f -not -type l | grep -v '/\(.git\|.hg\|.bzr\|_darcs\)/') || true
+	special=$(find . -not -type d -not -type f -not -type l | grep -v '/\(.git\|.hg\|.bzr\|_darcs\)/') || true
 	if [ -n "$special" ]; then
 		echo "etckeeper warning: special files could cause problems with $VCS:" >&2
 		echo "$special" >&2

=== modified file 'update-ignore.d/01update-ignore'
--- update-ignore.d/01update-ignore	2010-02-18 14:01:45 +0000
+++ update-ignore.d/01update-ignore	2010-04-15 11:50:22 +0000
@@ -119,6 +119,7 @@
 	ignore nologin
 	ignore ld.so.cache
 	ignore mtab
+	ignore mtab.fuselock
 	ignore .pwd.lock
 	ignore network/run
 	ignore adjtime

